//-*-c++-*-

#include "tulip/Types.h"
#include "tulip/Colors.h"
#include "tulip/SuperGraph.h"
#include "tulip/ColorsProxy.h"

Colors::Colors (const PropertyContext &context):Property<ColorType , ColorType>(context) {
  colorsProxy=(ColorsProxy *)context.propertyProxy;
}

